@@ -1,5 +1,5 @@
 #' Save a figure
-#' 
+#'
 #' @param x the keyATM_fig object.
 #' @param filename file name to create on disk.
 #' @param ... other arguments passed on to the [ggplot2::ggsave()][ggplot2::ggsave] function.
@@ -11,7 +11,7 @@ save_fig <- function(x, filename, ...) {
 
 
 #' Get values used to create a figure
-#' 
+#'
 #' @param x the keyATM_fig object.
 #' @seealso [save_fig()], [visualize_keywords()], [plot_alpha()], [plot_modelfit()], [plot_pi()], [plot_timetrend()], [by_strata_DocTopic()]
 #' @export
@@ -23,7 +23,7 @@ values_fig <- function(x) {
 #' @export
 values_fig.keyATM_fig <- function(x)
 {
-  return(x$values) 
+  return(x$values)
 }
 
 
@@ -39,7 +39,7 @@ save_fig.keyATM_fig <- function(x, filename, ...)
 #' @export
 print.keyATM_fig <- function(x, ...)
 {
-  print(x$figure) 
+  print(x$figure)
 }
 
 
@@ -48,7 +48,7 @@ print.keyATM_fig <- function(x, ...)
 #' @param x the output from a keyATM model (see [keyATM()]).
 #' @param start integer. The start of slice iteration. Default is \code{0}.
 #' @param show_topic a vector to specify topic indexes to show. Default is \code{NULL}.
-#' @param scales character. Control the scale of y-axis (the parameter in [ggplot2::facet_wrap()][ggplot2::facet_wrap]): \code{free} adjusts y-axis for parameters. Default is \code{fixed}. 
+#' @param scales character. Control the scale of y-axis (the parameter in [ggplot2::facet_wrap()][ggplot2::facet_wrap]): \code{free} adjusts y-axis for parameters. Default is \code{fixed}.
 #' @return keyATM_fig object
 #' @import ggplot2
 #' @import magrittr
@@ -70,7 +70,7 @@ plot_alpha <- function(x, start = 0, show_topic = NULL, scales = "fixed")
     show_topic <- 1:x$keyword_k
   }
   if (!is.numeric(start) | length(start) != 1) {
-    stop("`start` argument is invalid.")  
+    stop("`start` argument is invalid.")
   }
 
   tnames <- c(names(x$keywords_raw))[show_topic]
@@ -101,7 +101,7 @@ plot_alpha <- function(x, start = 0, show_topic = NULL, scales = "fixed")
           facet_wrap(~ .data$Topic, ncol = 2, scales = scales) +
           xlab("Iteration") + ylab("Value") +
           ggtitle("Estimated alpha") + theme_bw() +
-          theme(plot.title = element_text(hjust = 0.5))  
+          theme(plot.title = element_text(hjust = 0.5))
   }
 
   p <- list(figure = p, values = res_alpha)
@@ -111,7 +111,7 @@ plot_alpha <- function(x, start = 0, show_topic = NULL, scales = "fixed")
 
 
 #' Show a diagnosis plot of log-likelihood and perplexity
-#' 
+#'
 #' @param x the output from a keyATM model (see [keyATM()]).
 #' @param start integer. The starting value of iteration to use in plot. Default is \code{1}.
 #' @return keyATM_fig object.
@@ -126,7 +126,7 @@ plot_modelfit <- function(x, start = 1)
   modelfit <- x$model_fit
 
   if (!is.numeric(start) | length(start) != 1) {
-    stop("`start` argument is invalid.")  
+    stop("`start` argument is invalid.")
   }
 
   if (!is.null(start)) {
@@ -170,17 +170,17 @@ plot_pi <- function(x, show_topic = NULL, start = 0, ci = 0.9, method = c("hdi",
   modelname <- extract_full_model_name(x)
 
   if (modelname %in% c("lda", "ldacov", "ldahmm")) {
-    stop(paste0("This is not a model with keywords.")) 
+    stop(paste0("This is not a model with keywords."))
   }
 
   if (is.null(show_topic)) {
     show_topic <- 1:x$keyword_k
   } else if (sum(!show_topic %in% 1:x$keyword_k) != 0) {
-    stop("`plot_pi` only visualize keyword topics.") 
+    stop("`plot_pi` only visualize keyword topics.")
   }
 
   if (!is.numeric(start) | length(start) != 1) {
-    stop("`start` argument is invalid.")  
+    stop("`start` argument is invalid.")
   }
 
   tnames <- c(names(x$keywords_raw))[show_topic]
@@ -190,7 +190,7 @@ plot_pi <- function(x, show_topic = NULL, start = 0, ci = 0.9, method = c("hdi",
     pi_mat %>%
       tibble::as_tibble(.name_repair = ~ tnames) %>%
       dplyr::mutate(Iteration = x$values_iter$used_iter) %>%
-      dplyr::filter(.data$Iteration >= start) %>% 
+      dplyr::filter(.data$Iteration >= start) %>%
       dplyr::select(-.data$Iteration) -> pi_mat
 
     if (nrow(pi_mat) == 0) {
@@ -199,13 +199,13 @@ plot_pi <- function(x, show_topic = NULL, start = 0, ci = 0.9, method = c("hdi",
 
     pi_mat %>%
       tidyr::pivot_longer(cols = dplyr::everything(), names_to = "Topic") %>%
-      dplyr::group_by(.data$Topic) %>% 
+      dplyr::group_by(.data$Topic) %>%
       dplyr::summarise(x = list(tibble::enframe(calc_ci(.data$value, ci, method, point), "q", "value")), .groups = "drop_last") %>%
       tidyr::unnest(x) %>% tidyr::pivot_wider(names_from = .data$q, values_from = .data$value) -> temp
-    
-    p <- ggplot(temp, aes(y = .data$Point, x = .data$Topic)) + 
+
+    p <- ggplot(temp, aes(y = .data$Point, x = .data$Topic)) +
          theme_bw() + geom_point() +
-         geom_errorbar(aes(ymin = .data$Lower, ymax = .data$Upper), data = temp, width = 0.01, size = 1) + 
+         geom_errorbar(aes(ymin = .data$Lower, ymax = .data$Upper), data = temp, width = 0.01, size = 1) +
          xlab("Topic") + ylab("Probability") +
          ggtitle("Probability of words drawn from keyword topic-word distribution") +
          theme(plot.title = element_text(hjust = 0.5))
@@ -220,7 +220,7 @@ plot_pi <- function(x, show_topic = NULL, start = 0, ci = 0.9, method = c("hdi",
          theme_bw() +
          xlab("Topic") + ylab("Probability") +
          ggtitle("Probability of words drawn from keyword topic-word distribution") +
-         theme(plot.title = element_text(hjust = 0.5))    
+         theme(plot.title = element_text(hjust = 0.5))
   }
   p <- list(figure = p, values = temp)
   class(p) <- c("keyATM_fig", class(p))
@@ -229,7 +229,7 @@ plot_pi <- function(x, show_topic = NULL, start = 0, ci = 0.9, method = c("hdi",
 
 
 #' Plot document-topic distribution by strata (for covariate models)
-#' 
+#'
 #' @param x a strata_doctopic object (see [by_strata_DocTopic()]).
 #' @param show_topic a vector or an integer. Indicate topics to visualize.
 #' @param var_name the name of the variable in the plot.
@@ -262,7 +262,7 @@ plot.strata_doctopic <- function(x, show_topic = NULL, var_name = NULL, by = c("
   }
 
   if (is.null(show_topic)) {
-    show_topic <- 1:nrow(tables[[1]]) 
+    show_topic <- 1:nrow(tables[[1]])
   }
 
   tables <- dplyr::bind_rows(tables)
@@ -291,12 +291,12 @@ plot.strata_doctopic <- function(x, show_topic = NULL, var_name = NULL, by = c("
 
   if (by == "topic") {
     p <- p + geom_errorbar(width = width, aes(x = .data$label, ymin = .data$Lower, ymax = .data$Upper,
-                group = .data$Topic), position = position_dodge(width = -1/2)) + facet_wrap(~Topic) 
+                group = .data$Topic), position = position_dodge(width = -1/2)) + facet_wrap(~Topic)
     if (show_point)
       p <- p + geom_point(aes(x = .data$label, y = .data$Point))
   } else {
     p <- p + geom_errorbar(width = width, aes(x = .data$label, ymin = .data$Lower, ymax = .data$Upper,
-                group = .data$Topic, colour = .data$Topic), position = position_dodge(width = -1/2))   
+                group = .data$Topic, colour = .data$Topic), position = position_dodge(width = -1/2))
     if (show_point)
       p <- p + geom_point(aes(x = .data$label, y = .data$Point, colour = .data$Topic), position = position_dodge(width = -1/2))
   }
@@ -308,16 +308,15 @@ plot.strata_doctopic <- function(x, show_topic = NULL, var_name = NULL, by = c("
 
 
 #' Plot time trend
-#' 
+#'
 #' @param x the output from the dynamic keyATM model (see [keyATM()]).
 #' @param show_topic an integer or a vector. Indicate topics to visualize. Default is \code{NULL}.
-#' @param time_index_label a vector. The label for time index. The length should be equal to the number of documents (time index provided to [keyATM()]). 
+#' @param time_index_label a vector. The label for time index. The length should be equal to the number of documents (time index provided to [keyATM()]).
 #' @param ci value of the credible interval (between 0 and 1) to be estimated. Default is \code{0.9} (90%). This is an option when calculating credible intervals (you need to set \code{store_theta = TRUE} in [keyATM()]).
 #' @param method method for computing the credible interval. The Highest Density Interval (\code{hdi}, default) or Equal-tailed Interval (\code{eti}). This is an option when calculating credible intervals (you need to set \code{store_theta = TRUE} in [keyATM()]).
 #' @param point method for computing the point estimate. \code{mean} (default) or \code{median}. This is an option when calculating credible intervals (you need to set \code{store_theta = TRUE} in [keyATM()]).
 #' @param xlab a character.
-#' @param scales character. Control the scale of y-axis (the parameter in [ggplot2::facet_wrap()][ggplot2::facet_wrap]): \code{free} adjusts y-axis for parameters. Default is \code{fixed}. 
-#' @param width numeric. Width of the error bars.
+#' @param scales character. Control the scale of y-axis (the parameter in [ggplot2::facet_wrap()][ggplot2::facet_wrap]): \code{free} adjusts y-axis for parameters. Default is \code{fixed}.
 #' @param show_point logical. The default is \code{TRUE}. This is an option when calculating credible intervals.
 #' @param ... additional arguments not used.
 #' @return keyATM_fig object.
@@ -326,16 +325,16 @@ plot.strata_doctopic <- function(x, show_topic = NULL, var_name = NULL, by = c("
 #' @importFrom rlang .data
 #' @seealso [save_fig()]
 #' @export
-plot_timetrend <- function(x, show_topic = NULL, time_index_label = NULL, 
+plot_timetrend <- function(x, show_topic = NULL, time_index_label = NULL,
                            ci = 0.9, method = c("hdi", "eti"), point = c("mean", "median"),
-                           xlab = "Time", scales = "fixed", width = 0.5, show_point = TRUE, ...)
+                           xlab = "Time", scales = "fixed", show_point = TRUE, ...)
 {
   method <- match.arg(method)
   point <- match.arg(point)
   check_arg_type(x, "keyATM_output")
   modelname <- extract_full_model_name(x)
   if (!modelname %in% c("hmm", "ldahmm")) {
-    stop(paste0("This is not a model with keywords.")) 
+    stop(paste0("This is not a model with time trends."))
   }
 
   if (!is.null(time_index_label)) {
@@ -365,12 +364,12 @@ plot_timetrend <- function(x, show_topic = NULL, time_index_label = NULL,
 
   if (is.null(x$values_iter$theta_iter)) {
     dat <- format_theta(x$theta, time_index, tnames[show_topic])
-    p <- ggplot(dat, aes(x = .data$time_index, y = .data$Proportion, group = .data$Topic)) + 
+    p <- ggplot(dat, aes(x = .data$time_index, y = .data$Proportion, group = .data$Topic)) +
           geom_line(size = 0.8, color = "blue") + geom_point(size = 0.9)
   } else {
     dplyr::bind_rows(lapply(x$values_iter$theta_iter, format_theta, time_index, tnames[show_topic])) %>%
       dplyr::group_by(.data$time_index, .data$Topic) %>%
-      dplyr::summarise(x = list(tibble::enframe(calc_ci(.data$Proportion, ci, method, point), "q", "value"))) %>% 
+      dplyr::summarise(x = list(tibble::enframe(calc_ci(.data$Proportion, ci, method, point), "q", "value"))) %>%
       tidyr::unnest(.data$x) %>% dplyr::ungroup() %>%
       tidyr::pivot_wider(names_from = .data$q, values_from = .data$value) %>%
       stats::setNames(c("time_index", "Topic", "Lower", "Point", "Upper")) -> dat
