@@ -20,15 +20,11 @@ class keyATMbase : virtual public keyATMmeta
     int estimate_alpha;
     int store_alpha;
 
-    double start, end, previous_p, new_p, newlikelihood, slice_;
     std::vector<int> topic_ids;
     VectorXd keep_current_param;
     double store_loglik;
     double newalphallk;
 
-    double loglik;
-    double fixed_part;
-
       // in alpha_loglik
       MatrixXd ndk_a;
     
@@ -47,10 +43,10 @@ class keyATMbase : virtual public keyATMmeta
     void initialize_specific();
 
     // Iteration
-    virtual void iteration_single(int &it);
-    void sample_parameters(int &it);
+    virtual void iteration_single(int it);
+    void sample_parameters(int it);
     void sample_alpha();
-    double alpha_loglik(int &k);
+    double alpha_loglik(int k);
     virtual double loglik_total();
     double loglik_total_label();
 };
